==> hasktags-0.71.2-167-x86_64.pkg.tar.zst: usr/share/haskell/register/hasktags.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasktags
version:              0.71.2
visibility:           public
id:                   hasktags-0.71.2-6JWc6TLQsIA55IcskCf3Im
key:                  hasktags-0.71.2-6JWc6TLQsIA55IcskCf3Im
license:              BSD-3-Clause
copyright:            The University Court of the University of Glasgow
maintainer:
    Jack Henahan <jhenahan@me.com>,
    Marc Weber <marco-oweber@gmx.de>,
    Marco Túlio Pimenta Gontijo <marcotmarcot@gmail.com>

author:               The GHC Team
homepage:             http://github.com/MarcWeber/hasktags
synopsis:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs

description:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs.

category:             Development
abi:                  2ac03b7eb3b8409ecff61682d0a481bb
exposed:              True
exposed-modules:      Hasktags
hidden-modules:       Tags DebugShow
import-dirs:          /usr/lib/ghc-8.10.4/site-local/hasktags-0.71.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/hasktags-0.71.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/hasktags-0.71.2
hs-libraries:         HShasktags-0.71.2-6JWc6TLQsIA55IcskCf3Im
depends:
    base-4.14.1.0 bytestring-0.10.12.0 directory-1.3.6.0
    filepath-1.4.2.1 json-0.10-HWpUQMeg3GOJxEhxEXFbe0
    microlens-platform-0.4.2-18kGDv5Bc7iAMWxPg4oIAd
    utf8-string-1.0.2-7pqBkplor7g1hjwTjVt3SV

haddock-interfaces:   /usr/share/doc/hasktags/html/hasktags.haddock
haddock-html:         /usr/share/doc/hasktags/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hasktags-0.71.2-171-x86_64.pkg.tar.zst: usr/share/haskell/register/hasktags.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasktags
version:              0.71.2
visibility:           public
id:                   hasktags-0.71.2-JlaRKjduEx25elfKQ5b9Qg
key:                  hasktags-0.71.2-JlaRKjduEx25elfKQ5b9Qg
license:              BSD-3-Clause
copyright:            The University Court of the University of Glasgow
maintainer:
    Jack Henahan <jhenahan@me.com>,
    Marc Weber <marco-oweber@gmx.de>,
    Marco Túlio Pimenta Gontijo <marcotmarcot@gmail.com>

author:               The GHC Team
homepage:             http://github.com/MarcWeber/hasktags
synopsis:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs

description:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs.

category:             Development
abi:                  05298ea2cf1bf50b73d39b3d565f8bc7
exposed:              True
exposed-modules:      Hasktags
hidden-modules:       Tags DebugShow
import-dirs:          /usr/lib/ghc-8.10.5/site-local/hasktags-0.71.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/hasktags-0.71.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/hasktags-0.71.2
hs-libraries:         HShasktags-0.71.2-JlaRKjduEx25elfKQ5b9Qg
depends:
    base-4.14.2.0 bytestring-0.10.12.0 directory-1.3.6.0
    filepath-1.4.2.1 json-0.10-HaoBzwrR3D3IgYeLJ3gSvU
    microlens-platform-0.4.2-EgAALDEl1bbvVF2UGe97D
    utf8-string-1.0.2-DMovLmOdbFr3ZT2kNNb9Du

haddock-interfaces:   /usr/share/doc/hasktags/html/hasktags.haddock
haddock-html:         /usr/share/doc/hasktags/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
